@@ -574,7 +574,7 @@ class CommandRunner(BaseCommandRunner):
                     len(record_handler.modifiers.get_modifiers(read=2)) > 0 or
                     options.quality_cutoff)):
             logger.warning('\n'.join(textwrap.wrap(
-                'WARNING: Requested read modifications are applied only to the '
+                'Requested read modifications are applied only to the '
                 'first read since backwards compatibility mode is enabled. '
                 'To modify both reads, also use any of the -A/-B/-G/-U '
                 'options. Use a dummy adapter sequence when necessary: '
@@ -758,7 +758,7 @@ class CommandRunner(BaseCommandRunner):
                 self.cur_batch = None
             
             def start(self, worker):
-                super().__init__(worker)
+                super().start(worker)
                 self.pending = PendingQueue()
                 self.cur_batch = 1
             
@@ -778,7 +778,7 @@ class CommandRunner(BaseCommandRunner):
                             "OrderPreservingWriterResultHandler finishing "
                             "without having seen {} batches".format(
                                 total_batches))
-                self.writers.close()
+                super().finish(total_batches=total_batches)
             
             def consume_pending(self):
                 """Consume any remaining items in the queue.
